Syntax Checker: added a syntax checker for TOML files.

Sun, 04 Oct 2020 18:53:35 +0200

author
Detlev Offenbach <detlev@die-offenbachs.de>
date
Sun, 04 Oct 2020 18:53:35 +0200
changeset 7756
c23a94f7e2e5
parent 7755
1f0a5024360c
child 7757
1f9f35f9be6d

Syntax Checker: added a syntax checker for TOML files.

docs/changelog file | annotate | diff | comparison | revisions
eric6.e4p file | annotate | diff | comparison | revisions
eric6/APIs/Python3/eric6.api file | annotate | diff | comparison | revisions
eric6/Documentation/Help/source.qch file | annotate | diff | comparison | revisions
eric6/Documentation/Help/source.qhp file | annotate | diff | comparison | revisions
eric6/Documentation/Source/eric6.Globals.__init__.html file | annotate | diff | comparison | revisions
eric6/Documentation/Source/eric6.Plugins.CheckerPlugins.SyntaxChecker.SyntaxCheckService.html file | annotate | diff | comparison | revisions
eric6/Documentation/Source/eric6.Plugins.CheckerPlugins.SyntaxChecker.tomlCheckSyntax.html file | annotate | diff | comparison | revisions
eric6/Documentation/Source/eric6.Preferences.ConfigurationDialog.html file | annotate | diff | comparison | revisions
eric6/Documentation/Source/eric6.QScintilla.EditorOutline.html file | annotate | diff | comparison | revisions
eric6/Documentation/Source/eric6.QScintilla.QsciScintillaCompat.html file | annotate | diff | comparison | revisions
eric6/Documentation/Source/index-eric6.Plugins.CheckerPlugins.SyntaxChecker.html file | annotate | diff | comparison | revisions
eric6/Plugins/CheckerPlugins/SyntaxChecker/SyntaxCheckService.py file | annotate | diff | comparison | revisions
eric6/Plugins/CheckerPlugins/SyntaxChecker/tomlCheckSyntax.py file | annotate | diff | comparison | revisions
eric6/Plugins/PluginSyntaxChecker.py file | annotate | diff | comparison | revisions
eric6/i18n/eric6_cs.ts file | annotate | diff | comparison | revisions
eric6/i18n/eric6_de.qm file | annotate | diff | comparison | revisions
eric6/i18n/eric6_de.ts file | annotate | diff | comparison | revisions
eric6/i18n/eric6_empty.ts file | annotate | diff | comparison | revisions
eric6/i18n/eric6_en.ts file | annotate | diff | comparison | revisions
eric6/i18n/eric6_es.ts file | annotate | diff | comparison | revisions
eric6/i18n/eric6_fr.ts file | annotate | diff | comparison | revisions
eric6/i18n/eric6_it.ts file | annotate | diff | comparison | revisions
eric6/i18n/eric6_pt.ts file | annotate | diff | comparison | revisions
eric6/i18n/eric6_ru.ts file | annotate | diff | comparison | revisions
eric6/i18n/eric6_tr.ts file | annotate | diff | comparison | revisions
eric6/i18n/eric6_zh_CN.ts file | annotate | diff | comparison | revisions
--- a/docs/changelog	Sun Oct 04 18:03:33 2020 +0200
+++ b/docs/changelog	Sun Oct 04 18:53:35 2020 +0200
@@ -4,6 +4,8 @@
 - bug fixes
 - Editor
   -- added support for TOML files
+- Syntax Checker
+  -- added a syntax checker for TOML files
 
 Version 20.10:
 - bug fixes
--- a/eric6.e4p	Sun Oct 04 18:03:33 2020 +0200
+++ b/eric6.e4p	Sun Oct 04 18:53:35 2020 +0200
@@ -365,6 +365,7 @@
     <Source>eric6/Plugins/CheckerPlugins/SyntaxChecker/pyflakes/checker.py</Source>
     <Source>eric6/Plugins/CheckerPlugins/SyntaxChecker/pyflakes/messages.py</Source>
     <Source>eric6/Plugins/CheckerPlugins/SyntaxChecker/pyflakes/translations.py</Source>
+    <Source>eric6/Plugins/CheckerPlugins/SyntaxChecker/tomlCheckSyntax.py</Source>
     <Source>eric6/Plugins/CheckerPlugins/SyntaxChecker/yamlCheckSyntax.py</Source>
     <Source>eric6/Plugins/CheckerPlugins/__init__.py</Source>
     <Source>eric6/Plugins/DocumentationPlugins/Ericapi/EricapiConfigDialog.py</Source>
--- a/eric6/APIs/Python3/eric6.api	Sun Oct 04 18:03:33 2020 +0200
+++ b/eric6/APIs/Python3/eric6.api	Sun Oct 04 18:53:35 2020 +0200
@@ -1843,7 +1843,6 @@
 eric6.Globals.toByteArray?4(value)
 eric6.Globals.toDict?4(value)
 eric6.Globals.toList?4(value)
-eric6.Globals.translate?4(*args)
 eric6.Globals.versionToTuple?4(version, length=3)
 eric6.Graphics.ApplicationDiagramBuilder.ApplicationDiagramBuilder.buildDiagram?4()
 eric6.Graphics.ApplicationDiagramBuilder.ApplicationDiagramBuilder.getPersistenceData?4()
@@ -3429,6 +3428,7 @@
 eric6.Plugins.CheckerPlugins.SyntaxChecker.SyntaxCheckService.SyntaxCheckService.serviceErrorJSON?4(fx, lang, fn, msg)
 eric6.Plugins.CheckerPlugins.SyntaxChecker.SyntaxCheckService.SyntaxCheckService.serviceErrorJavaScript?4(fx, lang, fn, msg)
 eric6.Plugins.CheckerPlugins.SyntaxChecker.SyntaxCheckService.SyntaxCheckService.serviceErrorPy3?4(fx, lang, fn, msg)
+eric6.Plugins.CheckerPlugins.SyntaxChecker.SyntaxCheckService.SyntaxCheckService.serviceErrorTOML?4(fx, lang, fn, msg)
 eric6.Plugins.CheckerPlugins.SyntaxChecker.SyntaxCheckService.SyntaxCheckService.serviceErrorYAML?4(fx, lang, fn, msg)
 eric6.Plugins.CheckerPlugins.SyntaxChecker.SyntaxCheckService.SyntaxCheckService.syntaxBatchCheck?4(argumentsList)
 eric6.Plugins.CheckerPlugins.SyntaxChecker.SyntaxCheckService.SyntaxCheckService.syntaxCheck?4(lang, filename, source)
@@ -3460,6 +3460,12 @@
 eric6.Plugins.CheckerPlugins.SyntaxChecker.jsonCheckSyntax.jsonSyntaxCheck?4(file, codestring)
 eric6.Plugins.CheckerPlugins.SyntaxChecker.jsonCheckSyntax.normalizeCode?4(codestring)
 eric6.Plugins.CheckerPlugins.SyntaxChecker.jsonCheckSyntax.worker?4(inputQueue, outputQueue)
+eric6.Plugins.CheckerPlugins.SyntaxChecker.tomlCheckSyntax.initBatchService?4()
+eric6.Plugins.CheckerPlugins.SyntaxChecker.tomlCheckSyntax.initService?4()
+eric6.Plugins.CheckerPlugins.SyntaxChecker.tomlCheckSyntax.normalizeCode?4(codestring)
+eric6.Plugins.CheckerPlugins.SyntaxChecker.tomlCheckSyntax.tomlSyntaxBatchCheck?4(argumentsList, send, fx, cancelled, maxProcesses=0)
+eric6.Plugins.CheckerPlugins.SyntaxChecker.tomlCheckSyntax.tomlSyntaxCheck?4(file, codestring)
+eric6.Plugins.CheckerPlugins.SyntaxChecker.tomlCheckSyntax.worker?4(inputQueue, outputQueue)
 eric6.Plugins.CheckerPlugins.SyntaxChecker.yamlCheckSyntax.initBatchService?4()
 eric6.Plugins.CheckerPlugins.SyntaxChecker.yamlCheckSyntax.initService?4()
 eric6.Plugins.CheckerPlugins.SyntaxChecker.yamlCheckSyntax.normalizeCode?4(codestring)
@@ -6139,6 +6145,7 @@
 eric6.Preferences.ConfigurationDialog.ConfigurationWidget.on_resetButton_clicked?4()
 eric6.Preferences.ConfigurationDialog.ConfigurationWidget.preferencesChanged?7
 eric6.Preferences.ConfigurationDialog.ConfigurationWidget.rejected?7
+eric6.Preferences.ConfigurationDialog.ConfigurationWidget.resizeEvent?4(evt)
 eric6.Preferences.ConfigurationDialog.ConfigurationWidget.setPreferences?4()
 eric6.Preferences.ConfigurationDialog.ConfigurationWidget.showConfigurationPageByName?4(pageName, setCurrent=True)
 eric6.Preferences.ConfigurationDialog.ConfigurationWidget?1(parent=None, fromEric=True, displayMode=DefaultMode, expandedEntries=None)
@@ -7537,7 +7544,6 @@
 eric6.QScintilla.EditorMarkerMap.EditorMarkerMap._paintIt?5(painter)
 eric6.QScintilla.EditorMarkerMap.EditorMarkerMap.initColors?4()
 eric6.QScintilla.EditorMarkerMap.EditorMarkerMap?1(parent=None)
-eric6.QScintilla.EditorOutline.EditorOutlineView.WidthIncrement?7
 eric6.QScintilla.EditorOutline.EditorOutlineView.isPopulated?4()
 eric6.QScintilla.EditorOutline.EditorOutlineView.isSupportedLanguage?4(language)
 eric6.QScintilla.EditorOutline.EditorOutlineView.mouseDoubleClickEvent?4(mouseEvent)
@@ -8137,7 +8143,6 @@
 eric6.QScintilla.QsciScintillaCompat.QsciScintillaCompat.extendSelectionToEOL?4()
 eric6.QScintilla.QsciScintillaCompat.QsciScintillaCompat.extendSelectionWordLeft?4()
 eric6.QScintilla.QsciScintillaCompat.QsciScintillaCompat.extendSelectionWordRight?4()
-eric6.QScintilla.QsciScintillaCompat.QsciScintillaCompat.findFirst?4(expression, regexp, caseSensitive, word, wrap, forward=True, line=-1, index=-1, show=True, posix=False, cxx11=False)
 eric6.QScintilla.QsciScintillaCompat.QsciScintillaCompat.findFirstTarget?4(expr_, re_, cs_, wo_, begline=-1, begindex=-1, endline=-1, endindex=-1, ws_=False, posix=False, cxx11=False)
 eric6.QScintilla.QsciScintillaCompat.QsciScintillaCompat.findNextTarget?4()
 eric6.QScintilla.QsciScintillaCompat.QsciScintillaCompat.flashFindIndicator?4(sline, sindex, eline, eindex)
@@ -8170,7 +8175,6 @@
 eric6.QScintilla.QsciScintillaCompat.QsciScintillaCompat.hideFindIndicator?4()
 eric6.QScintilla.QsciScintillaCompat.QsciScintillaCompat.indentationGuideView?4()
 eric6.QScintilla.QsciScintillaCompat.QsciScintillaCompat.indicatorDefine?4(indicator, style, color)
-eric6.QScintilla.QsciScintillaCompat.QsciScintillaCompat.insert?4(txt)
 eric6.QScintilla.QsciScintillaCompat.QsciScintillaCompat.isModified?4()
 eric6.QScintilla.QsciScintillaCompat.QsciScintillaCompat.lineAt?4(pos)
 eric6.QScintilla.QsciScintillaCompat.QsciScintillaCompat.lineEndPosition?4(line)
Binary file eric6/Documentation/Help/source.qch has changed
--- a/eric6/Documentation/Help/source.qhp	Sun Oct 04 18:03:33 2020 +0200
+++ b/eric6/Documentation/Help/source.qhp	Sun Oct 04 18:53:35 2020 +0200
@@ -349,6 +349,7 @@
                 <section title="eric6.Plugins.CheckerPlugins.SyntaxChecker.SyntaxCheckerDialog" ref="eric6.Plugins.CheckerPlugins.SyntaxChecker.SyntaxCheckerDialog.html" />
                 <section title="eric6.Plugins.CheckerPlugins.SyntaxChecker.jsCheckSyntax" ref="eric6.Plugins.CheckerPlugins.SyntaxChecker.jsCheckSyntax.html" />
                 <section title="eric6.Plugins.CheckerPlugins.SyntaxChecker.jsonCheckSyntax" ref="eric6.Plugins.CheckerPlugins.SyntaxChecker.jsonCheckSyntax.html" />
+                <section title="eric6.Plugins.CheckerPlugins.SyntaxChecker.tomlCheckSyntax" ref="eric6.Plugins.CheckerPlugins.SyntaxChecker.tomlCheckSyntax.html" />
                 <section title="eric6.Plugins.CheckerPlugins.SyntaxChecker.yamlCheckSyntax" ref="eric6.Plugins.CheckerPlugins.SyntaxChecker.yamlCheckSyntax.html" />
               </section>
             </section>
@@ -2910,6 +2911,7 @@
       <keyword name="ConfigurationWidget.__importConfigurationPage" id="ConfigurationWidget.__importConfigurationPage" ref="eric6.Preferences.ConfigurationDialog.html#ConfigurationWidget.__importConfigurationPage" />
       <keyword name="ConfigurationWidget.__initLexers" id="ConfigurationWidget.__initLexers" ref="eric6.Preferences.ConfigurationDialog.html#ConfigurationWidget.__initLexers" />
       <keyword name="ConfigurationWidget.__initPage" id="ConfigurationWidget.__initPage" ref="eric6.Preferences.ConfigurationDialog.html#ConfigurationWidget.__initPage" />
+      <keyword name="ConfigurationWidget.__resizeConfigStack" id="ConfigurationWidget.__resizeConfigStack" ref="eric6.Preferences.ConfigurationDialog.html#ConfigurationWidget.__resizeConfigStack" />
       <keyword name="ConfigurationWidget.__searchChildItems" id="ConfigurationWidget.__searchChildItems" ref="eric6.Preferences.ConfigurationDialog.html#ConfigurationWidget.__searchChildItems" />
       <keyword name="ConfigurationWidget.__searchTextChanged" id="ConfigurationWidget.__searchTextChanged" ref="eric6.Preferences.ConfigurationDialog.html#ConfigurationWidget.__searchTextChanged" />
       <keyword name="ConfigurationWidget.__setupUi" id="ConfigurationWidget.__setupUi" ref="eric6.Preferences.ConfigurationDialog.html#ConfigurationWidget.__setupUi" />
@@ -2926,6 +2928,7 @@
       <keyword name="ConfigurationWidget.on_configList_itemCollapsed" id="ConfigurationWidget.on_configList_itemCollapsed" ref="eric6.Preferences.ConfigurationDialog.html#ConfigurationWidget.on_configList_itemCollapsed" />
       <keyword name="ConfigurationWidget.on_configList_itemExpanded" id="ConfigurationWidget.on_configList_itemExpanded" ref="eric6.Preferences.ConfigurationDialog.html#ConfigurationWidget.on_configList_itemExpanded" />
       <keyword name="ConfigurationWidget.on_resetButton_clicked" id="ConfigurationWidget.on_resetButton_clicked" ref="eric6.Preferences.ConfigurationDialog.html#ConfigurationWidget.on_resetButton_clicked" />
+      <keyword name="ConfigurationWidget.resizeEvent" id="ConfigurationWidget.resizeEvent" ref="eric6.Preferences.ConfigurationDialog.html#ConfigurationWidget.resizeEvent" />
       <keyword name="ConfigurationWidget.setPreferences" id="ConfigurationWidget.setPreferences" ref="eric6.Preferences.ConfigurationDialog.html#ConfigurationWidget.setPreferences" />
       <keyword name="ConfigurationWidget.showConfigurationPageByName" id="ConfigurationWidget.showConfigurationPageByName" ref="eric6.Preferences.ConfigurationDialog.html#ConfigurationWidget.showConfigurationPageByName" />
       <keyword name="ConfigurationWindow" id="ConfigurationWindow" ref="eric6.Preferences.ConfigurationDialog.html#ConfigurationWindow" />
@@ -5264,6 +5267,7 @@
       <keyword name="EditorOutlineView.__createPopupMenus" id="EditorOutlineView.__createPopupMenus" ref="eric6.QScintilla.EditorOutline.html#EditorOutlineView.__createPopupMenus" />
       <keyword name="EditorOutlineView.__currentItem" id="EditorOutlineView.__currentItem" ref="eric6.QScintilla.EditorOutline.html#EditorOutlineView.__currentItem" />
       <keyword name="EditorOutlineView.__decWidth" id="EditorOutlineView.__decWidth" ref="eric6.QScintilla.EditorOutline.html#EditorOutlineView.__decWidth" />
+      <keyword name="EditorOutlineView.__defaultWidth" id="EditorOutlineView.__defaultWidth" ref="eric6.QScintilla.EditorOutline.html#EditorOutlineView.__defaultWidth" />
       <keyword name="EditorOutlineView.__editorCursorLineChanged" id="EditorOutlineView.__editorCursorLineChanged" ref="eric6.QScintilla.EditorOutline.html#EditorOutlineView.__editorCursorLineChanged" />
       <keyword name="EditorOutlineView.__editorLanguageChanged" id="EditorOutlineView.__editorLanguageChanged" ref="eric6.QScintilla.EditorOutline.html#EditorOutlineView.__editorLanguageChanged" />
       <keyword name="EditorOutlineView.__editorRenamed" id="EditorOutlineView.__editorRenamed" ref="eric6.QScintilla.EditorOutline.html#EditorOutlineView.__editorRenamed" />
@@ -12128,7 +12132,6 @@
       <keyword name="QsciScintillaCompat.extendSelectionToEOL" id="QsciScintillaCompat.extendSelectionToEOL" ref="eric6.QScintilla.QsciScintillaCompat.html#QsciScintillaCompat.extendSelectionToEOL" />
       <keyword name="QsciScintillaCompat.extendSelectionWordLeft" id="QsciScintillaCompat.extendSelectionWordLeft" ref="eric6.QScintilla.QsciScintillaCompat.html#QsciScintillaCompat.extendSelectionWordLeft" />
       <keyword name="QsciScintillaCompat.extendSelectionWordRight" id="QsciScintillaCompat.extendSelectionWordRight" ref="eric6.QScintilla.QsciScintillaCompat.html#QsciScintillaCompat.extendSelectionWordRight" />
-      <keyword name="QsciScintillaCompat.findFirst" id="QsciScintillaCompat.findFirst" ref="eric6.QScintilla.QsciScintillaCompat.html#QsciScintillaCompat.findFirst" />
       <keyword name="QsciScintillaCompat.findFirstTarget" id="QsciScintillaCompat.findFirstTarget" ref="eric6.QScintilla.QsciScintillaCompat.html#QsciScintillaCompat.findFirstTarget" />
       <keyword name="QsciScintillaCompat.findNextTarget" id="QsciScintillaCompat.findNextTarget" ref="eric6.QScintilla.QsciScintillaCompat.html#QsciScintillaCompat.findNextTarget" />
       <keyword name="QsciScintillaCompat.flashFindIndicator" id="QsciScintillaCompat.flashFindIndicator" ref="eric6.QScintilla.QsciScintillaCompat.html#QsciScintillaCompat.flashFindIndicator" />
@@ -12161,7 +12164,6 @@
       <keyword name="QsciScintillaCompat.hideFindIndicator" id="QsciScintillaCompat.hideFindIndicator" ref="eric6.QScintilla.QsciScintillaCompat.html#QsciScintillaCompat.hideFindIndicator" />
       <keyword name="QsciScintillaCompat.indentationGuideView" id="QsciScintillaCompat.indentationGuideView" ref="eric6.QScintilla.QsciScintillaCompat.html#QsciScintillaCompat.indentationGuideView" />
       <keyword name="QsciScintillaCompat.indicatorDefine" id="QsciScintillaCompat.indicatorDefine" ref="eric6.QScintilla.QsciScintillaCompat.html#QsciScintillaCompat.indicatorDefine" />
-      <keyword name="QsciScintillaCompat.insert" id="QsciScintillaCompat.insert" ref="eric6.QScintilla.QsciScintillaCompat.html#QsciScintillaCompat.insert" />
       <keyword name="QsciScintillaCompat.isModified" id="QsciScintillaCompat.isModified" ref="eric6.QScintilla.QsciScintillaCompat.html#QsciScintillaCompat.isModified" />
       <keyword name="QsciScintillaCompat.lineAt" id="QsciScintillaCompat.lineAt" ref="eric6.QScintilla.QsciScintillaCompat.html#QsciScintillaCompat.lineAt" />
       <keyword name="QsciScintillaCompat.lineEndPosition" id="QsciScintillaCompat.lineEndPosition" ref="eric6.QScintilla.QsciScintillaCompat.html#QsciScintillaCompat.lineEndPosition" />
@@ -14466,6 +14468,7 @@
       <keyword name="SyntaxCheckService.serviceErrorJSON" id="SyntaxCheckService.serviceErrorJSON" ref="eric6.Plugins.CheckerPlugins.SyntaxChecker.SyntaxCheckService.html#SyntaxCheckService.serviceErrorJSON" />
       <keyword name="SyntaxCheckService.serviceErrorJavaScript" id="SyntaxCheckService.serviceErrorJavaScript" ref="eric6.Plugins.CheckerPlugins.SyntaxChecker.SyntaxCheckService.html#SyntaxCheckService.serviceErrorJavaScript" />
       <keyword name="SyntaxCheckService.serviceErrorPy3" id="SyntaxCheckService.serviceErrorPy3" ref="eric6.Plugins.CheckerPlugins.SyntaxChecker.SyntaxCheckService.html#SyntaxCheckService.serviceErrorPy3" />
+      <keyword name="SyntaxCheckService.serviceErrorTOML" id="SyntaxCheckService.serviceErrorTOML" ref="eric6.Plugins.CheckerPlugins.SyntaxChecker.SyntaxCheckService.html#SyntaxCheckService.serviceErrorTOML" />
       <keyword name="SyntaxCheckService.serviceErrorYAML" id="SyntaxCheckService.serviceErrorYAML" ref="eric6.Plugins.CheckerPlugins.SyntaxChecker.SyntaxCheckService.html#SyntaxCheckService.serviceErrorYAML" />
       <keyword name="SyntaxCheckService.syntaxBatchCheck" id="SyntaxCheckService.syntaxBatchCheck" ref="eric6.Plugins.CheckerPlugins.SyntaxChecker.SyntaxCheckService.html#SyntaxCheckService.syntaxBatchCheck" />
       <keyword name="SyntaxCheckService.syntaxCheck" id="SyntaxCheckService.syntaxCheck" ref="eric6.Plugins.CheckerPlugins.SyntaxChecker.SyntaxCheckService.html#SyntaxCheckService.syntaxCheck" />
@@ -16990,6 +16993,7 @@
       <keyword name="__setAction" id="__setAction" ref="eric6.Preferences.Shortcuts.html#__setAction" />
       <keyword name="__showwarning" id="__showwarning" ref="eric6.Utilities.__init__.html#__showwarning" />
       <keyword name="__syntaxAndPyflakesCheck" id="__syntaxAndPyflakesCheck" ref="eric6.Plugins.CheckerPlugins.SyntaxChecker.SyntaxCheck.html#__syntaxAndPyflakesCheck" />
+      <keyword name="__tomlSyntaxCheck" id="__tomlSyntaxCheck" ref="eric6.Plugins.CheckerPlugins.SyntaxChecker.tomlCheckSyntax.html#__tomlSyntaxCheck" />
       <keyword name="__yamlSyntaxCheck" id="__yamlSyntaxCheck" ref="eric6.Plugins.CheckerPlugins.SyntaxChecker.yamlCheckSyntax.html#__yamlSyntaxCheck" />
       <keyword name="_add_check" id="_add_check" ref="eric6.Plugins.CheckerPlugins.CodeStyleChecker.pycodestyle.html#_add_check" />
       <keyword name="_break_around_binary_operators" id="_break_around_binary_operators" ref="eric6.Plugins.CheckerPlugins.CodeStyleChecker.pycodestyle.html#_break_around_binary_operators" />
@@ -17567,6 +17571,7 @@
       <keyword name="initBatchService" id="initBatchService" ref="eric6.Plugins.CheckerPlugins.SyntaxChecker.SyntaxCheck.html#initBatchService" />
       <keyword name="initBatchService" id="initBatchService" ref="eric6.Plugins.CheckerPlugins.SyntaxChecker.jsCheckSyntax.html#initBatchService" />
       <keyword name="initBatchService" id="initBatchService" ref="eric6.Plugins.CheckerPlugins.SyntaxChecker.jsonCheckSyntax.html#initBatchService" />
+      <keyword name="initBatchService" id="initBatchService" ref="eric6.Plugins.CheckerPlugins.SyntaxChecker.tomlCheckSyntax.html#initBatchService" />
       <keyword name="initBatchService" id="initBatchService" ref="eric6.Plugins.CheckerPlugins.SyntaxChecker.yamlCheckSyntax.html#initBatchService" />
       <keyword name="initDebugger" id="initDebugger" ref="eric6.DebugClients.Python.eric6dbgstub.html#initDebugger" />
       <keyword name="initGlobals" id="initGlobals" ref="install-debugclients.html#initGlobals" />
@@ -17581,6 +17586,7 @@
       <keyword name="initService" id="initService" ref="eric6.Plugins.CheckerPlugins.SyntaxChecker.SyntaxCheck.html#initService" />
       <keyword name="initService" id="initService" ref="eric6.Plugins.CheckerPlugins.SyntaxChecker.jsCheckSyntax.html#initService" />
       <keyword name="initService" id="initService" ref="eric6.Plugins.CheckerPlugins.SyntaxChecker.jsonCheckSyntax.html#initService" />
+      <keyword name="initService" id="initService" ref="eric6.Plugins.CheckerPlugins.SyntaxChecker.tomlCheckSyntax.html#initService" />
       <keyword name="initService" id="initService" ref="eric6.Plugins.CheckerPlugins.SyntaxChecker.yamlCheckSyntax.html#initService" />
       <keyword name="initializeResourceSearchPath" id="initializeResourceSearchPath" ref="eric6.Toolbox.Startup.html#initializeResourceSearchPath" />
       <keyword name="injectionParamiko (Module)" id="injectionParamiko (Module)" ref="eric6.Plugins.CheckerPlugins.CodeStyleChecker.Security.Checks.injectionParamiko.html" />
@@ -17707,6 +17713,7 @@
       <keyword name="normalizeCode" id="normalizeCode" ref="eric6.Plugins.CheckerPlugins.SyntaxChecker.SyntaxCheck.html#normalizeCode" />
       <keyword name="normalizeCode" id="normalizeCode" ref="eric6.Plugins.CheckerPlugins.SyntaxChecker.jsCheckSyntax.html#normalizeCode" />
       <keyword name="normalizeCode" id="normalizeCode" ref="eric6.Plugins.CheckerPlugins.SyntaxChecker.jsonCheckSyntax.html#normalizeCode" />
+      <keyword name="normalizeCode" id="normalizeCode" ref="eric6.Plugins.CheckerPlugins.SyntaxChecker.tomlCheckSyntax.html#normalizeCode" />
       <keyword name="normalizeCode" id="normalizeCode" ref="eric6.Plugins.CheckerPlugins.SyntaxChecker.yamlCheckSyntax.html#normalizeCode" />
       <keyword name="normalize_paths" id="normalize_paths" ref="eric6.Plugins.CheckerPlugins.CodeStyleChecker.pycodestyle.html#normalize_paths" />
       <keyword name="normalize_ws" id="normalize_ws" ref="eric6.E5Network.E5RFC6266.html#normalize_ws" />
@@ -17931,10 +17938,12 @@
       <keyword name="toList" id="toList" ref="eric6.Preferences.__init__.html#toList" />
       <keyword name="toNativeSeparators" id="toNativeSeparators" ref="eric6.Utilities.__init__.html#toNativeSeparators" />
       <keyword name="toSecondLevelDomain" id="toSecondLevelDomain" ref="eric6.WebBrowser.AdBlock.AdBlockRule.html#toSecondLevelDomain" />
+      <keyword name="tomlCheckSyntax (Module)" id="tomlCheckSyntax (Module)" ref="eric6.Plugins.CheckerPlugins.SyntaxChecker.tomlCheckSyntax.html" />
+      <keyword name="tomlSyntaxBatchCheck" id="tomlSyntaxBatchCheck" ref="eric6.Plugins.CheckerPlugins.SyntaxChecker.tomlCheckSyntax.html#tomlSyntaxBatchCheck" />
+      <keyword name="tomlSyntaxCheck" id="tomlSyntaxCheck" ref="eric6.Plugins.CheckerPlugins.SyntaxChecker.tomlCheckSyntax.html#tomlSyntaxCheck" />
       <keyword name="trailing_blank_lines" id="trailing_blank_lines" ref="eric6.Plugins.CheckerPlugins.CodeStyleChecker.pycodestyle.html#trailing_blank_lines" />
       <keyword name="trailing_whitespace" id="trailing_whitespace" ref="eric6.Plugins.CheckerPlugins.CodeStyleChecker.pycodestyle.html#trailing_whitespace" />
       <keyword name="transform2call" id="transform2call" ref="eric6.Plugins.CheckerPlugins.CodeStyleChecker.Security.Checks.djangoXssVulnerability.html#transform2call" />
-      <keyword name="translate" id="translate" ref="eric6.Globals.__init__.html#translate" />
       <keyword name="translations (Module)" id="translations (Module)" ref="eric6.Plugins.CheckerPlugins.CodeStyleChecker.Security.translations.html" />
       <keyword name="translations (Module)" id="translations (Module)" ref="eric6.Plugins.CheckerPlugins.CodeStyleChecker.translations.html" />
       <keyword name="tryExcept (Module)" id="tryExcept (Module)" ref="eric6.Plugins.CheckerPlugins.CodeStyleChecker.Security.Checks.tryExcept.html" />
@@ -17998,6 +18007,7 @@
       <keyword name="worker" id="worker" ref="eric6.Plugins.CheckerPlugins.SyntaxChecker.SyntaxCheck.html#worker" />
       <keyword name="worker" id="worker" ref="eric6.Plugins.CheckerPlugins.SyntaxChecker.jsCheckSyntax.html#worker" />
       <keyword name="worker" id="worker" ref="eric6.Plugins.CheckerPlugins.SyntaxChecker.jsonCheckSyntax.html#worker" />
+      <keyword name="worker" id="worker" ref="eric6.Plugins.CheckerPlugins.SyntaxChecker.tomlCheckSyntax.html#worker" />
       <keyword name="worker" id="worker" ref="eric6.Plugins.CheckerPlugins.SyntaxChecker.yamlCheckSyntax.html#worker" />
       <keyword name="wrapperNames" id="wrapperNames" ref="install.html#wrapperNames" />
       <keyword name="wrapperNames" id="wrapperNames" ref="uninstall.html#wrapperNames" />
@@ -18290,6 +18300,7 @@
       <file>eric6.Plugins.CheckerPlugins.SyntaxChecker.SyntaxCheckerDialog.html</file>
       <file>eric6.Plugins.CheckerPlugins.SyntaxChecker.jsCheckSyntax.html</file>
       <file>eric6.Plugins.CheckerPlugins.SyntaxChecker.jsonCheckSyntax.html</file>
+      <file>eric6.Plugins.CheckerPlugins.SyntaxChecker.tomlCheckSyntax.html</file>
       <file>eric6.Plugins.CheckerPlugins.SyntaxChecker.yamlCheckSyntax.html</file>
       <file>eric6.Plugins.DocumentationPlugins.Ericapi.EricapiConfigDialog.html</file>
       <file>eric6.Plugins.DocumentationPlugins.Ericapi.EricapiExecDialog.html</file>
--- a/eric6/Documentation/Source/eric6.Globals.__init__.html	Sun Oct 04 18:03:33 2020 +0200
+++ b/eric6/Documentation/Source/eric6.Globals.__init__.html	Sun Oct 04 18:53:35 2020 +0200
@@ -132,10 +132,6 @@
 <td>Module function to convert a value to a list.</td>
 </tr>
 <tr>
-<td><a href="#translate">translate</a></td>
-<td>Module function to handle different PyQt 4/5 QCoreApplication.translate parameter.</td>
-</tr>
-<tr>
 <td><a href="#versionToTuple">versionToTuple</a></td>
 <td>Module function to convert a version string into a tuple.</td>
 </tr>
@@ -281,7 +277,13 @@
 <dl>
 <dt>Returns:</dt>
 <dd>
-path of the Qt binaries (string)
+path of the Qt binaries
+</dd>
+</dl>
+<dl>
+<dt>Return Type:</dt>
+<dd>
+str
 </dd>
 </dl>
 <div align="right"><a href="#top">Up</a></div>
@@ -644,30 +646,6 @@
 <div align="right"><a href="#top">Up</a></div>
 <hr />
 <hr />
-<a NAME="translate" ID="translate"></a>
-<h2>translate</h2>
-<b>translate</b>(<i>*args</i>)
-
-<p>
-    Module function to handle different PyQt 4/5 QCoreApplication.translate
-    parameter.
-</p>
-<dl>
-
-<dt><i>args</i></dt>
-<dd>
-tuple of arguments from QCoreApplication.translate (tuple)
-</dd>
-</dl>
-<dl>
-<dt>Returns:</dt>
-<dd>
-translated string (string)
-</dd>
-</dl>
-<div align="right"><a href="#top">Up</a></div>
-<hr />
-<hr />
 <a NAME="versionToTuple" ID="versionToTuple"></a>
 <h2>versionToTuple</h2>
 <b>versionToTuple</b>(<i>version, length=3</i>)
--- a/eric6/Documentation/Source/eric6.Plugins.CheckerPlugins.SyntaxChecker.SyntaxCheckService.html	Sun Oct 04 18:03:33 2020 +0200
+++ b/eric6/Documentation/Source/eric6.Plugins.CheckerPlugins.SyntaxChecker.SyntaxCheckService.html	Sun Oct 04 18:53:35 2020 +0200
@@ -140,6 +140,10 @@
 <td>Public method handling service errors for Python 3.</td>
 </tr>
 <tr>
+<td><a href="#SyntaxCheckService.serviceErrorTOML">serviceErrorTOML</a></td>
+<td>Public method handling service errors for TOML.</td>
+</tr>
+<tr>
 <td><a href="#SyntaxCheckService.serviceErrorYAML">serviceErrorYAML</a></td>
 <td>Public method handling service errors for YAML.</td>
 </tr>
@@ -396,6 +400,32 @@
 message text (string)
 </dd>
 </dl>
+<a NAME="SyntaxCheckService.serviceErrorTOML" ID="SyntaxCheckService.serviceErrorTOML"></a>
+<h4>SyntaxCheckService.serviceErrorTOML</h4>
+<b>serviceErrorTOML</b>(<i>fx, lang, fn, msg</i>)
+
+<p>
+        Public method handling service errors for TOML.
+</p>
+<dl>
+
+<dt><i>fx</i></dt>
+<dd>
+service name (string)
+</dd>
+<dt><i>lang</i></dt>
+<dd>
+language (string)
+</dd>
+<dt><i>fn</i></dt>
+<dd>
+file name (string)
+</dd>
+<dt><i>msg</i></dt>
+<dd>
+message text (string)
+</dd>
+</dl>
 <a NAME="SyntaxCheckService.serviceErrorYAML" ID="SyntaxCheckService.serviceErrorYAML"></a>
 <h4>SyntaxCheckService.serviceErrorYAML</h4>
 <b>serviceErrorYAML</b>(<i>fx, lang, fn, msg</i>)
--- /dev/null	Thu Jan 01 00:00:00 1970 +0000
+++ b/eric6/Documentation/Source/eric6.Plugins.CheckerPlugins.SyntaxChecker.tomlCheckSyntax.html	Sun Oct 04 18:53:35 2020 +0200
@@ -0,0 +1,271 @@
+<!DOCTYPE html>
+<html><head>
+<title>eric6.Plugins.CheckerPlugins.SyntaxChecker.tomlCheckSyntax</title>
+<meta charset="UTF-8">
+<style>
+body {
+    background: #EDECE6;
+    margin: 0em 1em 10em 1em;
+    color: black;
+}
+
+h1 { color: white; background: #85774A; }
+h2 { color: white; background: #85774A; }
+h3 { color: white; background: #9D936E; }
+h4 { color: white; background: #9D936E; }
+    
+a { color: #BA6D36; }
+
+</style>
+</head>
+<body>
+<a NAME="top" ID="top"></a>
+<h1>eric6.Plugins.CheckerPlugins.SyntaxChecker.tomlCheckSyntax</h1>
+
+<p>
+Module implementing the syntax check for TOML.
+</p>
+<h3>Global Attributes</h3>
+
+<table>
+<tr><td>None</td></tr>
+</table>
+<h3>Classes</h3>
+
+<table>
+<tr><td>None</td></tr>
+</table>
+<h3>Functions</h3>
+
+<table>
+
+<tr>
+<td><a href="#__tomlSyntaxCheck">__tomlSyntaxCheck</a></td>
+<td>Function to check a TOML source file for syntax errors.</td>
+</tr>
+<tr>
+<td><a href="#initBatchService">initBatchService</a></td>
+<td>Initialize the batch service and return the entry point.</td>
+</tr>
+<tr>
+<td><a href="#initService">initService</a></td>
+<td>Initialize the service and return the entry point.</td>
+</tr>
+<tr>
+<td><a href="#normalizeCode">normalizeCode</a></td>
+<td>Function to normalize the given code.</td>
+</tr>
+<tr>
+<td><a href="#tomlSyntaxBatchCheck">tomlSyntaxBatchCheck</a></td>
+<td>Module function to check syntax for a batch of files.</td>
+</tr>
+<tr>
+<td><a href="#tomlSyntaxCheck">tomlSyntaxCheck</a></td>
+<td>Function to check a TOML source file for syntax errors.</td>
+</tr>
+<tr>
+<td><a href="#worker">worker</a></td>
+<td>Module function acting as the parallel worker for the syntax check.</td>
+</tr>
+</table>
+<hr />
+<hr />
+<a NAME="__tomlSyntaxCheck" ID="__tomlSyntaxCheck"></a>
+<h2>__tomlSyntaxCheck</h2>
+<b>__tomlSyntaxCheck</b>(<i>file, codestring</i>)
+
+<p>
+    Function to check a TOML source file for syntax errors.
+</p>
+<dl>
+
+<dt><i>file</i> (str)</dt>
+<dd>
+source filename
+</dd>
+<dt><i>codestring</i> (str)</dt>
+<dd>
+string containing the code to check
+</dd>
+</dl>
+<dl>
+<dt>Returns:</dt>
+<dd>
+dictionary with the keys 'error' and 'warnings' which
+            hold a list containing details about the error/ warnings
+            (file name, line number, column, codestring (only at syntax
+            errors), the message, a list with arguments for the message)
+</dd>
+</dl>
+<dl>
+<dt>Return Type:</dt>
+<dd>
+dict
+</dd>
+</dl>
+<div align="right"><a href="#top">Up</a></div>
+<hr />
+<hr />
+<a NAME="initBatchService" ID="initBatchService"></a>
+<h2>initBatchService</h2>
+<b>initBatchService</b>(<i></i>)
+
+<p>
+    Initialize the batch service and return the entry point.
+</p>
+<dl>
+<dt>Returns:</dt>
+<dd>
+the entry point for the background client
+</dd>
+</dl>
+<dl>
+<dt>Return Type:</dt>
+<dd>
+func
+</dd>
+</dl>
+<div align="right"><a href="#top">Up</a></div>
+<hr />
+<hr />
+<a NAME="initService" ID="initService"></a>
+<h2>initService</h2>
+<b>initService</b>(<i></i>)
+
+<p>
+    Initialize the service and return the entry point.
+</p>
+<dl>
+<dt>Returns:</dt>
+<dd>
+the entry point for the background client
+</dd>
+</dl>
+<dl>
+<dt>Return Type:</dt>
+<dd>
+func
+</dd>
+</dl>
+<div align="right"><a href="#top">Up</a></div>
+<hr />
+<hr />
+<a NAME="normalizeCode" ID="normalizeCode"></a>
+<h2>normalizeCode</h2>
+<b>normalizeCode</b>(<i>codestring</i>)
+
+<p>
+    Function to normalize the given code.
+</p>
+<dl>
+
+<dt><i>codestring</i> (str)</dt>
+<dd>
+code to be normalized
+</dd>
+</dl>
+<dl>
+<dt>Returns:</dt>
+<dd>
+normalized code
+</dd>
+</dl>
+<dl>
+<dt>Return Type:</dt>
+<dd>
+str
+</dd>
+</dl>
+<div align="right"><a href="#top">Up</a></div>
+<hr />
+<hr />
+<a NAME="tomlSyntaxBatchCheck" ID="tomlSyntaxBatchCheck"></a>
+<h2>tomlSyntaxBatchCheck</h2>
+<b>tomlSyntaxBatchCheck</b>(<i>argumentsList, send, fx, cancelled, maxProcesses=0</i>)
+
+<p>
+    Module function to check syntax for a batch of files.
+</p>
+<dl>
+
+<dt><i>argumentsList</i> (list)</dt>
+<dd>
+list of arguments tuples as given for tomlSyntaxCheck
+</dd>
+<dt><i>send</i> (func)</dt>
+<dd>
+reference to send function
+</dd>
+<dt><i>fx</i> (str)</dt>
+<dd>
+registered service name
+</dd>
+<dt><i>cancelled</i> (func)</dt>
+<dd>
+reference to function checking for a cancellation
+</dd>
+<dt><i>maxProcesses</i> (int)</dt>
+<dd>
+number of processes to be used
+</dd>
+</dl>
+<div align="right"><a href="#top">Up</a></div>
+<hr />
+<hr />
+<a NAME="tomlSyntaxCheck" ID="tomlSyntaxCheck"></a>
+<h2>tomlSyntaxCheck</h2>
+<b>tomlSyntaxCheck</b>(<i>file, codestring</i>)
+
+<p>
+    Function to check a TOML source file for syntax errors.
+</p>
+<dl>
+
+<dt><i>file</i> (str)</dt>
+<dd>
+source filename
+</dd>
+<dt><i>codestring</i> (str)</dt>
+<dd>
+string containing the code to check
+</dd>
+</dl>
+<dl>
+<dt>Returns:</dt>
+<dd>
+dictionary with the keys 'error' and 'warnings' which
+            hold a list containing details about the error/ warnings
+            (file name, line number, column, codestring (only at syntax
+            errors), the message, a list with arguments for the message)
+</dd>
+</dl>
+<dl>
+<dt>Return Type:</dt>
+<dd>
+dict
+</dd>
+</dl>
+<div align="right"><a href="#top">Up</a></div>
+<hr />
+<hr />
+<a NAME="worker" ID="worker"></a>
+<h2>worker</h2>
+<b>worker</b>(<i>inputQueue, outputQueue</i>)
+
+<p>
+    Module function acting as the parallel worker for the syntax check.
+</p>
+<dl>
+
+<dt><i>inputQueue</i> (multiprocessing.Queue)</dt>
+<dd>
+input queue
+</dd>
+<dt><i>outputQueue</i> (multiprocessing.Queue)</dt>
+<dd>
+output queue
+</dd>
+</dl>
+<div align="right"><a href="#top">Up</a></div>
+<hr />
+</body></html>
\ No newline at end of file
--- a/eric6/Documentation/Source/eric6.Preferences.ConfigurationDialog.html	Sun Oct 04 18:03:33 2020 +0200
+++ b/eric6/Documentation/Source/eric6.Preferences.ConfigurationDialog.html	Sun Oct 04 18:53:35 2020 +0200
@@ -393,6 +393,10 @@
 <td>Private method to initialize a configuration page.</td>
 </tr>
 <tr>
+<td><a href="#ConfigurationWidget.__resizeConfigStack">__resizeConfigStack</a></td>
+<td>Private method to resize the stack of configuration pages.</td>
+</tr>
+<tr>
 <td><a href="#ConfigurationWidget.__searchChildItems">__searchChildItems</a></td>
 <td>Private method to enable child items based on a search string.</td>
 </tr>
@@ -457,6 +461,10 @@
 <td>Private slot called to reset the settings of the current page.</td>
 </tr>
 <tr>
+<td><a href="#ConfigurationWidget.resizeEvent">resizeEvent</a></td>
+<td>Protected method to handle the resizing of the widget.</td>
+</tr>
+<tr>
 <td><a href="#ConfigurationWidget.setPreferences">setPreferences</a></td>
 <td>Public method called to store the selected values into the preferences storage.</td>
 </tr>
@@ -555,6 +563,13 @@
 reference to the initialized page
 </dd>
 </dl>
+<a NAME="ConfigurationWidget.__resizeConfigStack" ID="ConfigurationWidget.__resizeConfigStack"></a>
+<h4>ConfigurationWidget.__resizeConfigStack</h4>
+<b>__resizeConfigStack</b>(<i></i>)
+
+<p>
+        Private method to resize the stack of configuration pages.
+</p>
 <a NAME="ConfigurationWidget.__searchChildItems" ID="ConfigurationWidget.__searchChildItems"></a>
 <h4>ConfigurationWidget.__searchChildItems</h4>
 <b>__searchChildItems</b>(<i>parent, text</i>)
@@ -774,6 +789,20 @@
 <p>
         Private slot called to reset the settings of the current page.
 </p>
+<a NAME="ConfigurationWidget.resizeEvent" ID="ConfigurationWidget.resizeEvent"></a>
+<h4>ConfigurationWidget.resizeEvent</h4>
+<b>resizeEvent</b>(<i>evt</i>)
+
+<p>
+        Protected method to handle the resizing of the widget.
+</p>
+<dl>
+
+<dt><i>evt</i> (QResizeEvent)</dt>
+<dd>
+reference to the event object
+</dd>
+</dl>
 <a NAME="ConfigurationWidget.setPreferences" ID="ConfigurationWidget.setPreferences"></a>
 <h4>ConfigurationWidget.setPreferences</h4>
 <b>setPreferences</b>(<i></i>)
--- a/eric6/Documentation/Source/eric6.QScintilla.EditorOutline.html	Sun Oct 04 18:03:33 2020 +0200
+++ b/eric6/Documentation/Source/eric6.QScintilla.EditorOutline.html	Sun Oct 04 18:53:35 2020 +0200
@@ -58,7 +58,7 @@
 <h3>Class Attributes</h3>
 
 <table>
-<tr><td>WidthIncrement</td></tr>
+<tr><td>None</td></tr>
 </table>
 <h3>Class Methods</h3>
 
@@ -95,7 +95,11 @@
 </tr>
 <tr>
 <td><a href="#EditorOutlineView.__decWidth">__decWidth</a></td>
-<td>Private method to decrement the width of the outline.</td>
+<td>Private slot to decrement the width of the outline.</td>
+</tr>
+<tr>
+<td><a href="#EditorOutlineView.__defaultWidth">__defaultWidth</a></td>
+<td>Private slot to set the outline to the default width.</td>
 </tr>
 <tr>
 <td><a href="#EditorOutlineView.__editorCursorLineChanged">__editorCursorLineChanged</a></td>
@@ -123,7 +127,7 @@
 </tr>
 <tr>
 <td><a href="#EditorOutlineView.__incWidth">__incWidth</a></td>
-<td>Private method to increment the width of the outline.</td>
+<td>Private slot to increment the width of the outline.</td>
 </tr>
 <tr>
 <td><a href="#EditorOutlineView.__prepareRepopulate">__prepareRepopulate</a></td>
@@ -245,7 +249,14 @@
 <b>__decWidth</b>(<i></i>)
 
 <p>
-        Private method to decrement the width of the outline.
+        Private slot to decrement the width of the outline.
+</p>
+<a NAME="EditorOutlineView.__defaultWidth" ID="EditorOutlineView.__defaultWidth"></a>
+<h4>EditorOutlineView.__defaultWidth</h4>
+<b>__defaultWidth</b>(<i></i>)
+
+<p>
+        Private slot to set the outline to the default width.
 </p>
 <a NAME="EditorOutlineView.__editorCursorLineChanged" ID="EditorOutlineView.__editorCursorLineChanged"></a>
 <h4>EditorOutlineView.__editorCursorLineChanged</h4>
@@ -316,7 +327,7 @@
 <b>__incWidth</b>(<i></i>)
 
 <p>
-        Private method to increment the width of the outline.
+        Private slot to increment the width of the outline.
 </p>
 <a NAME="EditorOutlineView.__prepareRepopulate" ID="EditorOutlineView.__prepareRepopulate"></a>
 <h4>EditorOutlineView.__prepareRepopulate</h4>
--- a/eric6/Documentation/Source/eric6.QScintilla.QsciScintillaCompat.html	Sun Oct 04 18:03:33 2020 +0200
+++ b/eric6/Documentation/Source/eric6.QScintilla.QsciScintillaCompat.html	Sun Oct 04 18:53:35 2020 +0200
@@ -230,10 +230,6 @@
 <td>Public method to extend the selection one word to the right.</td>
 </tr>
 <tr>
-<td><a href="#QsciScintillaCompat.findFirst">findFirst</a></td>
-<td>Public method to search in the current editor text.</td>
-</tr>
-<tr>
 <td><a href="#QsciScintillaCompat.findFirstTarget">findFirstTarget</a></td>
 <td>Public method to search in a specified range of text without setting the selection.</td>
 </tr>
@@ -362,10 +358,6 @@
 <td>Public method to define the appearance of an indicator.</td>
 </tr>
 <tr>
-<td><a href="#QsciScintillaCompat.insert">insert</a></td>
-<td>Public method to insert text at the cursor position.</td>
-</tr>
-<tr>
 <td><a href="#QsciScintillaCompat.isModified">isModified</a></td>
 <td>Public method to return the modification status.</td>
 </tr>
@@ -1007,73 +999,6 @@
 <p>
         Public method to extend the selection one word to the right.
 </p>
-<a NAME="QsciScintillaCompat.findFirst" ID="QsciScintillaCompat.findFirst"></a>
-<h4>QsciScintillaCompat.findFirst</h4>
-<b>findFirst</b>(<i>expression, regexp, caseSensitive, word, wrap, forward=True, line=-1, index=-1, show=True, posix=False, cxx11=False</i>)
-
-<p>
-        Public method to search in the current editor text.
-</p>
-<dl>
-
-<dt><i>expression</i> (str)</dt>
-<dd>
-search expression
-</dd>
-<dt><i>regexp</i> (bool)</dt>
-<dd>
-flag indicating a regular expression
-</dd>
-<dt><i>caseSensitive</i> (bool)</dt>
-<dd>
-flag indicating a case sensitive search
-</dd>
-<dt><i>word</i> (bool)</dt>
-<dd>
-flag indicating a word only search
-</dd>
-<dt><i>wrap</i> (bool)</dt>
-<dd>
-flag indicating to warp around
-</dd>
-<dt><i>forward</i> (bool)</dt>
-<dd>
-flag indicating the search direction
-</dd>
-<dt><i>line</i> (int)</dt>
-<dd>
-line to start the search on
-</dd>
-<dt><i>index</i> (int)</dt>
-<dd>
-index to start the search on
-</dd>
-<dt><i>show</i> (bool)</dt>
-<dd>
-flag indicating to set the selection to the found
-            expression
-</dd>
-<dt><i>posix</i> (bool)</dt>
-<dd>
-flag indicating the POSIX regular expression search mode
-</dd>
-<dt><i>cxx11</i> (bool)</dt>
-<dd>
-flag indicating the CXX11 regular expression search mode
-</dd>
-</dl>
-<dl>
-<dt>Returns:</dt>
-<dd>
-flag indicating a successful search
-</dd>
-</dl>
-<dl>
-<dt>Return Type:</dt>
-<dd>
-bool
-</dd>
-</dl>
 <a NAME="QsciScintillaCompat.findFirstTarget" ID="QsciScintillaCompat.findFirstTarget"></a>
 <h4>QsciScintillaCompat.findFirstTarget</h4>
 <b>findFirstTarget</b>(<i>expr_, re_, cs_, wo_, begline=-1, begindex=-1, endline=-1, endindex=-1, ws_=False, posix=False, cxx11=False</i>)
@@ -1734,20 +1659,6 @@
 the indicator or style are not valid
 </dd>
 </dl>
-<a NAME="QsciScintillaCompat.insert" ID="QsciScintillaCompat.insert"></a>
-<h4>QsciScintillaCompat.insert</h4>
-<b>insert</b>(<i>txt</i>)
-
-<p>
-            Public method to insert text at the cursor position.
-</p>
-<dl>
-
-<dt><i>txt</i> (str)</dt>
-<dd>
-text to be inserted
-</dd>
-</dl>
 <a NAME="QsciScintillaCompat.isModified" ID="QsciScintillaCompat.isModified"></a>
 <h4>QsciScintillaCompat.isModified</h4>
 <b>isModified</b>(<i></i>)
--- a/eric6/Documentation/Source/index-eric6.Plugins.CheckerPlugins.SyntaxChecker.html	Sun Oct 04 18:03:33 2020 +0200
+++ b/eric6/Documentation/Source/index-eric6.Plugins.CheckerPlugins.SyntaxChecker.html	Sun Oct 04 18:53:35 2020 +0200
@@ -50,6 +50,10 @@
 <td>Module implementing the syntax check for JSON.</td>
 </tr>
 <tr>
+<td><a href="eric6.Plugins.CheckerPlugins.SyntaxChecker.tomlCheckSyntax.html">tomlCheckSyntax</a></td>
+<td>Module implementing the syntax check for TOML.</td>
+</tr>
+<tr>
 <td><a href="eric6.Plugins.CheckerPlugins.SyntaxChecker.yamlCheckSyntax.html">yamlCheckSyntax</a></td>
 <td>Module implementing the syntax check for YAML.</td>
 </tr>
--- a/eric6/Plugins/CheckerPlugins/SyntaxChecker/SyntaxCheckService.py	Sun Oct 04 18:03:33 2020 +0200
+++ b/eric6/Plugins/CheckerPlugins/SyntaxChecker/SyntaxCheckService.py	Sun Oct 04 18:53:35 2020 +0200
@@ -257,6 +257,22 @@
                 self.__serviceError(self.tr("JSON batch check"), msg)
                 self.batchJobDone(fx, lang)
     
+    def serviceErrorTOML(self, fx, lang, fn, msg):
+        """
+        Public method handling service errors for TOML.
+        
+        @param fx service name (string)
+        @param lang language (string)
+        @param fn file name (string)
+        @param msg message text (string)
+        """
+        if fx in ['TOMLSyntax', 'batch_TOMLSyntax']:
+            if fx == 'TOMLSyntax':
+                self.__serviceError(fn, msg)
+            else:
+                self.__serviceError(self.tr("TOML batch check"), msg)
+                self.batchJobDone(fx, lang)
+    
     def batchJobDone(self, fx, lang):
         """
         Public slot handling the completion of a batch job.
@@ -269,6 +285,7 @@
             'JavaScriptSyntax', 'batch_JavaScriptSyntax',
             'YAMLSyntax', 'batch_YAMLSyntax',
             'JSONSyntax', 'batch_JSONSyntax',
+            'TOMLSyntax', 'batch_TOMLSyntax',
         ]:
             if lang in self.queuedBatches:
                 self.queuedBatches.remove(lang)
--- /dev/null	Thu Jan 01 00:00:00 1970 +0000
+++ b/eric6/Plugins/CheckerPlugins/SyntaxChecker/tomlCheckSyntax.py	Sun Oct 04 18:53:35 2020 +0200
@@ -0,0 +1,188 @@
+# -*- coding: utf-8 -*-
+
+# Copyright (c) 2020 Detlev Offenbach <detlev@die-offenbachs.de>
+#
+
+"""
+Module implementing the syntax check for TOML.
+"""
+
+import queue
+import multiprocessing
+
+
+def initService():
+    """
+    Initialize the service and return the entry point.
+    
+    @return the entry point for the background client
+    @rtype func
+    """
+    return tomlSyntaxCheck
+
+
+def initBatchService():
+    """
+    Initialize the batch service and return the entry point.
+    
+    @return the entry point for the background client
+    @rtype func
+    """
+    return tomlSyntaxBatchCheck
+
+
+def normalizeCode(codestring):
+    """
+    Function to normalize the given code.
+    
+    @param codestring code to be normalized
+    @type str
+    @return normalized code
+    @rtype str
+    """
+    codestring = codestring.replace("\r\n", "\n").replace("\r", "\n")
+
+    if codestring and codestring[-1] != '\n':
+        codestring = codestring + '\n'
+    
+    return codestring
+
+
+def tomlSyntaxCheck(file, codestring):
+    """
+    Function to check a TOML source file for syntax errors.
+    
+    @param file source filename
+    @type str
+    @param codestring string containing the code to check
+    @type str
+    @return dictionary with the keys 'error' and 'warnings' which
+            hold a list containing details about the error/ warnings
+            (file name, line number, column, codestring (only at syntax
+            errors), the message, a list with arguments for the message)
+    @rtype dict
+    """
+    return __tomlSyntaxCheck(file, codestring)
+
+
+def tomlSyntaxBatchCheck(argumentsList, send, fx, cancelled, maxProcesses=0):
+    """
+    Module function to check syntax for a batch of files.
+    
+    @param argumentsList list of arguments tuples as given for tomlSyntaxCheck
+    @type list
+    @param send reference to send function
+    @type func
+    @param fx registered service name
+    @type str
+    @param cancelled reference to function checking for a cancellation
+    @type func
+    @param maxProcesses number of processes to be used
+    @type int
+    """
+    if maxProcesses == 0:
+        # determine based on CPU count
+        try:
+            NumberOfProcesses = multiprocessing.cpu_count()
+            if NumberOfProcesses >= 1:
+                NumberOfProcesses -= 1
+        except NotImplementedError:
+            NumberOfProcesses = 1
+    else:
+        NumberOfProcesses = maxProcesses
+
+    # Create queues
+    taskQueue = multiprocessing.Queue()
+    doneQueue = multiprocessing.Queue()
+
+    # Submit tasks (initially two time number of processes
+    initialTasks = 2 * NumberOfProcesses
+    for task in argumentsList[:initialTasks]:
+        taskQueue.put(task)
+
+    # Start worker processes
+    for _ in range(NumberOfProcesses):
+        multiprocessing.Process(
+            target=worker, args=(taskQueue, doneQueue)
+        ).start()
+
+    # Get and send results
+    endIndex = len(argumentsList) - initialTasks
+    for i in range(len(argumentsList)):
+        resultSent = False
+        wasCancelled = False
+        
+        while not resultSent:
+            try:
+                # get result (waiting max. 3 seconds and send it to frontend
+                filename, result = doneQueue.get()
+                send(fx, filename, result)
+                resultSent = True
+            except queue.Empty:
+                # ignore empty queue, just carry on
+                if cancelled():
+                    wasCancelled = True
+                    break
+        
+        if wasCancelled or cancelled():
+            # just exit the loop ignoring the results of queued tasks
+            break
+        
+        if i < endIndex:
+            taskQueue.put(argumentsList[i + initialTasks])
+
+    # Tell child processes to stop
+    for _ in range(NumberOfProcesses):
+        taskQueue.put('STOP')
+
+
+def worker(inputQueue, outputQueue):
+    """
+    Module function acting as the parallel worker for the syntax check.
+    
+    @param inputQueue input queue
+    @type multiprocessing.Queue
+    @param outputQueue output queue
+    @type multiprocessing.Queue
+    """
+    for filename, args in iter(inputQueue.get, 'STOP'):
+        source = args[0]
+        result = __tomlSyntaxCheck(filename, source)
+        outputQueue.put((filename, result))
+
+
+def __tomlSyntaxCheck(file, codestring):
+    """
+    Function to check a TOML source file for syntax errors.
+    
+    @param file source filename
+    @type str
+    @param codestring string containing the code to check
+    @type str
+    @return dictionary with the keys 'error' and 'warnings' which
+            hold a list containing details about the error/ warnings
+            (file name, line number, column, codestring (only at syntax
+            errors), the message, a list with arguments for the message)
+    @rtype dict
+    """
+    try:
+        import toml
+    except ImportError:
+        error = "toml not available. Install it via the PyPI interface."
+        return [{'error': (file, 0, 0, '', error)}]
+    
+    codestring = normalizeCode(codestring)
+    
+    try:
+        toml.loads(codestring)
+    except toml.TomlDecodeError as exc:
+        line = exc.lineno
+        column = exc.colno
+        error = exc.msg
+        
+        cline = min(len(codestring.splitlines()), int(line)) - 1
+        code = codestring.splitlines()[cline]
+        
+        return [{'error': (file, line, column, code, error)}]
+    
+    return [{}]
--- a/eric6/i18n/eric6_cs.ts	Sun Oct 04 18:03:33 2020 +0200
+++ b/eric6/i18n/eric6_cs.ts	Sun Oct 04 18:53:35 2020 +0200
@@ -74158,6 +74158,11 @@
         <source>JSON batch check</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <location filename="../Plugins/CheckerPlugins/SyntaxChecker/SyntaxCheckService.py" line="273"/>
+        <source>TOML batch check</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>SyntaxCheckerDialog</name>
@@ -74269,22 +74274,22 @@
 <context>
     <name>SyntaxCheckerPlugin</name>
     <message>
-        <location filename="../Plugins/PluginSyntaxChecker.py" line="261"/>
+        <location filename="../Plugins/PluginSyntaxChecker.py" line="270"/>
         <source>Check Syntax</source>
         <translation>Kontrola syntaxe</translation>
     </message>
     <message>
-        <location filename="../Plugins/PluginSyntaxChecker.py" line="261"/>
+        <location filename="../Plugins/PluginSyntaxChecker.py" line="270"/>
         <source>&amp;Syntax...</source>
         <translation>&amp;Syntaxe...</translation>
     </message>
     <message>
-        <location filename="../Plugins/PluginSyntaxChecker.py" line="170"/>
+        <location filename="../Plugins/PluginSyntaxChecker.py" line="179"/>
         <source>Check syntax.</source>
         <translation>Kontrola syntaxe.</translation>
     </message>
     <message>
-        <location filename="../Plugins/PluginSyntaxChecker.py" line="265"/>
+        <location filename="../Plugins/PluginSyntaxChecker.py" line="274"/>
         <source>&lt;b&gt;Check Syntax...&lt;/b&gt;&lt;p&gt;This checks Python files for syntax errors.&lt;/p&gt;</source>
         <translation>&lt;b&gt;Kontrola Syntaxe...&lt;/b&gt;&lt;p&gt;Zkontroluje všechny Python soubory na syntaktické chyby.&lt;/p&gt;</translation>
     </message>
Binary file eric6/i18n/eric6_de.qm has changed
--- a/eric6/i18n/eric6_de.ts	Sun Oct 04 18:03:33 2020 +0200
+++ b/eric6/i18n/eric6_de.ts	Sun Oct 04 18:53:35 2020 +0200
@@ -1,6 +1,5 @@
 <?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS>
-<TS version="2.1" language="de">
+<!DOCTYPE TS><TS version="2.0" language="de" sourcelanguage="">
 <context>
     <name>AboutDialog</name>
     <message>
@@ -2053,8 +2052,8 @@
     </message>
     <message>
         <location filename="../WebBrowser/Bookmarks/BookmarksMenu.py" line="171"/>
-        <source>Open in New Tab	Ctrl+LMB</source>
-        <translation>In neuem Register öffnen	Strg+LMK</translation>
+        <source>Open in New Tab<byte value="x9"/>Ctrl+LMB</source>
+        <translation>In neuem Register öffnen<byte value="x9"/>Strg+LMK</translation>
     </message>
     <message>
         <location filename="../WebBrowser/Bookmarks/BookmarksMenu.py" line="175"/>
@@ -2122,8 +2121,8 @@
     </message>
     <message>
         <location filename="../WebBrowser/Bookmarks/BookmarksToolBar.py" line="91"/>
-        <source>Open in New Tab	Ctrl+LMB</source>
-        <translation>In neuem Register öffnen	Strg+LMK</translation>
+        <source>Open in New Tab<byte value="x9"/>Ctrl+LMB</source>
+        <translation>In neuem Register öffnen<byte value="x9"/>Strg+LMK</translation>
     </message>
     <message>
         <location filename="../WebBrowser/Bookmarks/BookmarksToolBar.py" line="95"/>
@@ -44312,12 +44311,12 @@
     </message>
     <message>
         <location filename="../MicroPython/MicroPythonWidget.py" line="1051"/>
-        <source>µPy Chart</source>
+        <source>&#xc2;&#xb5;Py Chart</source>
         <translation>µPy Chart</translation>
     </message>
     <message>
         <location filename="../MicroPython/MicroPythonWidget.py" line="1131"/>
-        <source>µPy Files</source>
+        <source>&#xc2;&#xb5;Py Files</source>
         <translation>µPy Dateien</translation>
     </message>
     <message>
@@ -70933,6 +70932,11 @@
         <source>JSON batch check</source>
         <translation>JSON Stapelprüfung</translation>
     </message>
+    <message>
+        <location filename="../Plugins/CheckerPlugins/SyntaxChecker/SyntaxCheckService.py" line="273"/>
+        <source>TOML batch check</source>
+        <translation>TOML Stapelprüfung</translation>
+    </message>
 </context>
 <context>
     <name>SyntaxCheckerDialog</name>
@@ -71046,22 +71050,22 @@
 <context>
     <name>SyntaxCheckerPlugin</name>
     <message>
-        <location filename="../Plugins/PluginSyntaxChecker.py" line="261"/>
+        <location filename="../Plugins/PluginSyntaxChecker.py" line="270"/>
         <source>Check Syntax</source>
         <translation>Syntax prüfen</translation>
     </message>
     <message>
-        <location filename="../Plugins/PluginSyntaxChecker.py" line="261"/>
+        <location filename="../Plugins/PluginSyntaxChecker.py" line="270"/>
         <source>&amp;Syntax...</source>
         <translation>&amp;Syntax...</translation>
     </message>
     <message>
-        <location filename="../Plugins/PluginSyntaxChecker.py" line="170"/>
+        <location filename="../Plugins/PluginSyntaxChecker.py" line="179"/>
         <source>Check syntax.</source>
         <translation>Syntax prüfen.</translation>
     </message>
     <message>
-        <location filename="../Plugins/PluginSyntaxChecker.py" line="265"/>
+        <location filename="../Plugins/PluginSyntaxChecker.py" line="274"/>
         <source>&lt;b&gt;Check Syntax...&lt;/b&gt;&lt;p&gt;This checks Python files for syntax errors.&lt;/p&gt;</source>
         <translation>&lt;b&gt;Syntax prüfen...&lt;/b&gt;&lt;p&gt;Dies überprüft Python-Dateien auf Syntaxfehler.&lt;/p&gt;</translation>
     </message>
@@ -84557,8 +84561,8 @@
     </message>
     <message>
         <location filename="../WebBrowser/WebBrowserView.py" line="676"/>
-        <source>Open Link in New Tab	Ctrl+LMB</source>
-        <translation>Link in neuem Fenster öffnen	Strg+LMK</translation>
+        <source>Open Link in New Tab<byte value="x9"/>Ctrl+LMB</source>
+        <translation>Link in neuem Fenster öffnen<byte value="x9"/>Strg+LMK</translation>
     </message>
     <message>
         <location filename="../WebBrowser/WebBrowserView.py" line="682"/>
--- a/eric6/i18n/eric6_empty.ts	Sun Oct 04 18:03:33 2020 +0200
+++ b/eric6/i18n/eric6_empty.ts	Sun Oct 04 18:53:35 2020 +0200
@@ -70355,6 +70355,11 @@
         <source>JSON batch check</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <location filename="../Plugins/CheckerPlugins/SyntaxChecker/SyntaxCheckService.py" line="273"/>
+        <source>TOML batch check</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>SyntaxCheckerDialog</name>
@@ -70462,22 +70467,22 @@
 <context>
     <name>SyntaxCheckerPlugin</name>
     <message>
-        <location filename="../Plugins/PluginSyntaxChecker.py" line="261"/>
+        <location filename="../Plugins/PluginSyntaxChecker.py" line="270"/>
         <source>Check Syntax</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../Plugins/PluginSyntaxChecker.py" line="261"/>
+        <location filename="../Plugins/PluginSyntaxChecker.py" line="270"/>
         <source>&amp;Syntax...</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../Plugins/PluginSyntaxChecker.py" line="170"/>
+        <location filename="../Plugins/PluginSyntaxChecker.py" line="179"/>
         <source>Check syntax.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../Plugins/PluginSyntaxChecker.py" line="265"/>
+        <location filename="../Plugins/PluginSyntaxChecker.py" line="274"/>
         <source>&lt;b&gt;Check Syntax...&lt;/b&gt;&lt;p&gt;This checks Python files for syntax errors.&lt;/p&gt;</source>
         <translation type="unfinished"></translation>
     </message>
--- a/eric6/i18n/eric6_en.ts	Sun Oct 04 18:03:33 2020 +0200
+++ b/eric6/i18n/eric6_en.ts	Sun Oct 04 18:53:35 2020 +0200
@@ -70400,6 +70400,11 @@
         <source>JSON batch check</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <location filename="../Plugins/CheckerPlugins/SyntaxChecker/SyntaxCheckService.py" line="273"/>
+        <source>TOML batch check</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>SyntaxCheckerDialog</name>
@@ -70507,22 +70512,22 @@
 <context>
     <name>SyntaxCheckerPlugin</name>
     <message>
-        <location filename="../Plugins/PluginSyntaxChecker.py" line="261"/>
+        <location filename="../Plugins/PluginSyntaxChecker.py" line="270"/>
         <source>Check Syntax</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../Plugins/PluginSyntaxChecker.py" line="261"/>
+        <location filename="../Plugins/PluginSyntaxChecker.py" line="270"/>
         <source>&amp;Syntax...</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../Plugins/PluginSyntaxChecker.py" line="170"/>
+        <location filename="../Plugins/PluginSyntaxChecker.py" line="179"/>
         <source>Check syntax.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../Plugins/PluginSyntaxChecker.py" line="265"/>
+        <location filename="../Plugins/PluginSyntaxChecker.py" line="274"/>
         <source>&lt;b&gt;Check Syntax...&lt;/b&gt;&lt;p&gt;This checks Python files for syntax errors.&lt;/p&gt;</source>
         <translation type="unfinished"></translation>
     </message>
--- a/eric6/i18n/eric6_es.ts	Sun Oct 04 18:03:33 2020 +0200
+++ b/eric6/i18n/eric6_es.ts	Sun Oct 04 18:53:35 2020 +0200
@@ -1,6 +1,5 @@
 <?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS>
-<TS version="2.1" language="es">
+<!DOCTYPE TS><TS version="2.0" language="es" sourcelanguage="">
 <context>
     <name>AboutDialog</name>
     <message>
@@ -2070,7 +2069,7 @@
     </message>
     <message>
         <location filename="../WebBrowser/Bookmarks/BookmarksMenu.py" line="171"/>
-        <source>Open in New Tab	Ctrl+LMB</source>
+        <source>Open in New Tab<byte value="x9"/>Ctrl+LMB</source>
         <translation>Abrir en Nueva Pestaña\tCtrl+LMB (botón izquierdo del ratón)</translation>
     </message>
 </context>
@@ -2149,7 +2148,7 @@
     </message>
     <message>
         <location filename="../WebBrowser/Bookmarks/BookmarksToolBar.py" line="91"/>
-        <source>Open in New Tab	Ctrl+LMB</source>
+        <source>Open in New Tab<byte value="x9"/>Ctrl+LMB</source>
         <translation>Abrir en Nueva Pestaña\tCtrl+LMB (botón izquierdo del ratón)</translation>
     </message>
 </context>
@@ -44314,12 +44313,12 @@
     </message>
     <message>
         <location filename="../MicroPython/MicroPythonWidget.py" line="1051"/>
-        <source>µPy Chart</source>
+        <source>&#xc2;&#xb5;Py Chart</source>
         <translation>Gráfica µPy</translation>
     </message>
     <message>
         <location filename="../MicroPython/MicroPythonWidget.py" line="1131"/>
-        <source>µPy Files</source>
+        <source>&#xc2;&#xb5;Py Files</source>
         <translation>Archivos µPy</translation>
     </message>
     <message>
@@ -70898,6 +70897,11 @@
         <source>JSON batch check</source>
         <translation>JSON comprobación por lotes</translation>
     </message>
+    <message>
+        <location filename="../Plugins/CheckerPlugins/SyntaxChecker/SyntaxCheckService.py" line="273"/>
+        <source>TOML batch check</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>SyntaxCheckerDialog</name>
@@ -71009,22 +71013,22 @@
 <context>
     <name>SyntaxCheckerPlugin</name>
     <message>
-        <location filename="../Plugins/PluginSyntaxChecker.py" line="261"/>
+        <location filename="../Plugins/PluginSyntaxChecker.py" line="270"/>
         <source>Check Syntax</source>
         <translation>Verificar sintaxis</translation>
     </message>
     <message>
-        <location filename="../Plugins/PluginSyntaxChecker.py" line="261"/>
+        <location filename="../Plugins/PluginSyntaxChecker.py" line="270"/>
         <source>&amp;Syntax...</source>
         <translation>&amp;Sintaxis...</translation>
     </message>
     <message>
-        <location filename="../Plugins/PluginSyntaxChecker.py" line="170"/>
+        <location filename="../Plugins/PluginSyntaxChecker.py" line="179"/>
         <source>Check syntax.</source>
         <translation>Verificar sintaxis.</translation>
     </message>
     <message>
-        <location filename="../Plugins/PluginSyntaxChecker.py" line="265"/>
+        <location filename="../Plugins/PluginSyntaxChecker.py" line="274"/>
         <source>&lt;b&gt;Check Syntax...&lt;/b&gt;&lt;p&gt;This checks Python files for syntax errors.&lt;/p&gt;</source>
         <translation>&lt;b&gt;Verificar Sintaxis...&lt;/b&gt;&lt;p&gt;Chequea archivos de Python buscando errores sintácticos.&lt;/p&gt;</translation>
     </message>
@@ -84778,7 +84782,7 @@
     </message>
     <message>
         <location filename="../WebBrowser/WebBrowserView.py" line="676"/>
-        <source>Open Link in New Tab	Ctrl+LMB</source>
+        <source>Open Link in New Tab<byte value="x9"/>Ctrl+LMB</source>
         <translation>Abrir enlace en nueva pestaña Tab\tCtrl+LMB (botón izquierdo del ratón)</translation>
     </message>
     <message>
--- a/eric6/i18n/eric6_fr.ts	Sun Oct 04 18:03:33 2020 +0200
+++ b/eric6/i18n/eric6_fr.ts	Sun Oct 04 18:53:35 2020 +0200
@@ -73474,6 +73474,11 @@
         <source>JSON batch check</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <location filename="../Plugins/CheckerPlugins/SyntaxChecker/SyntaxCheckService.py" line="273"/>
+        <source>TOML batch check</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>SyntaxCheckerDialog</name>
@@ -73583,22 +73588,22 @@
 <context>
     <name>SyntaxCheckerPlugin</name>
     <message>
-        <location filename="../Plugins/PluginSyntaxChecker.py" line="261"/>
+        <location filename="../Plugins/PluginSyntaxChecker.py" line="270"/>
         <source>Check Syntax</source>
         <translation>Vérification de la syntaxe</translation>
     </message>
     <message>
-        <location filename="../Plugins/PluginSyntaxChecker.py" line="261"/>
+        <location filename="../Plugins/PluginSyntaxChecker.py" line="270"/>
         <source>&amp;Syntax...</source>
         <translation>&amp;Syntaxe...</translation>
     </message>
     <message>
-        <location filename="../Plugins/PluginSyntaxChecker.py" line="170"/>
+        <location filename="../Plugins/PluginSyntaxChecker.py" line="179"/>
         <source>Check syntax.</source>
         <translation>Vérification de la syntaxe.</translation>
     </message>
     <message>
-        <location filename="../Plugins/PluginSyntaxChecker.py" line="265"/>
+        <location filename="../Plugins/PluginSyntaxChecker.py" line="274"/>
         <source>&lt;b&gt;Check Syntax...&lt;/b&gt;&lt;p&gt;This checks Python files for syntax errors.&lt;/p&gt;</source>
         <translation>&lt;b&gt;Vérification de la syntaxe...&lt;/b&gt;&lt;p&gt;Vérifie les erreurs de syntaxe des fichiers Python.&lt;/p&gt;</translation>
     </message>
--- a/eric6/i18n/eric6_it.ts	Sun Oct 04 18:03:33 2020 +0200
+++ b/eric6/i18n/eric6_it.ts	Sun Oct 04 18:53:35 2020 +0200
@@ -75971,6 +75971,11 @@
         <source>JSON batch check</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <location filename="../Plugins/CheckerPlugins/SyntaxChecker/SyntaxCheckService.py" line="273"/>
+        <source>TOML batch check</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>SyntaxCheckerDialog</name>
@@ -76083,22 +76088,22 @@
 <context>
     <name>SyntaxCheckerPlugin</name>
     <message>
-        <location filename="../Plugins/PluginSyntaxChecker.py" line="261"/>
+        <location filename="../Plugins/PluginSyntaxChecker.py" line="270"/>
         <source>Check Syntax</source>
         <translation>Controlla sintassi</translation>
     </message>
     <message>
-        <location filename="../Plugins/PluginSyntaxChecker.py" line="261"/>
+        <location filename="../Plugins/PluginSyntaxChecker.py" line="270"/>
         <source>&amp;Syntax...</source>
         <translation>&amp;Sintassi...</translation>
     </message>
     <message>
-        <location filename="../Plugins/PluginSyntaxChecker.py" line="170"/>
+        <location filename="../Plugins/PluginSyntaxChecker.py" line="179"/>
         <source>Check syntax.</source>
         <translation>Controlla sintassi.</translation>
     </message>
     <message>
-        <location filename="../Plugins/PluginSyntaxChecker.py" line="265"/>
+        <location filename="../Plugins/PluginSyntaxChecker.py" line="274"/>
         <source>&lt;b&gt;Check Syntax...&lt;/b&gt;&lt;p&gt;This checks Python files for syntax errors.&lt;/p&gt;</source>
         <translation>&lt;b&gt;Controlla sintassi...&lt;/b&gt;&lt;p&gt;Controlla i file Python per errori di sintassi.&lt;/p&gt;</translation>
     </message>
--- a/eric6/i18n/eric6_pt.ts	Sun Oct 04 18:03:33 2020 +0200
+++ b/eric6/i18n/eric6_pt.ts	Sun Oct 04 18:53:35 2020 +0200
@@ -75248,6 +75248,11 @@
         <source>JSON batch check</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <location filename="../Plugins/CheckerPlugins/SyntaxChecker/SyntaxCheckService.py" line="273"/>
+        <source>TOML batch check</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>SyntaxCheckerDialog</name>
@@ -75355,22 +75360,22 @@
 <context>
     <name>SyntaxCheckerPlugin</name>
     <message>
-        <location filename="../Plugins/PluginSyntaxChecker.py" line="261"/>
+        <location filename="../Plugins/PluginSyntaxChecker.py" line="270"/>
         <source>Check Syntax</source>
         <translation>Verificar Sintaxe</translation>
     </message>
     <message>
-        <location filename="../Plugins/PluginSyntaxChecker.py" line="261"/>
+        <location filename="../Plugins/PluginSyntaxChecker.py" line="270"/>
         <source>&amp;Syntax...</source>
         <translation>&amp;Sintaxe...</translation>
     </message>
     <message>
-        <location filename="../Plugins/PluginSyntaxChecker.py" line="170"/>
+        <location filename="../Plugins/PluginSyntaxChecker.py" line="179"/>
         <source>Check syntax.</source>
         <translation>Verificar sintaxe.</translation>
     </message>
     <message>
-        <location filename="../Plugins/PluginSyntaxChecker.py" line="265"/>
+        <location filename="../Plugins/PluginSyntaxChecker.py" line="274"/>
         <source>&lt;b&gt;Check Syntax...&lt;/b&gt;&lt;p&gt;This checks Python files for syntax errors.&lt;/p&gt;</source>
         <translation>&lt;b&gt;Verificar Sintaxe...&lt;/b&gt;&lt;b&gt;Verifica erros de  sintaxe nos ficheiros Python.&lt;/p&gt;</translation>
     </message>
--- a/eric6/i18n/eric6_ru.ts	Sun Oct 04 18:03:33 2020 +0200
+++ b/eric6/i18n/eric6_ru.ts	Sun Oct 04 18:53:35 2020 +0200
@@ -71185,6 +71185,11 @@
         <source>JSON batch check</source>
         <translation>Пакетная проверка JSON</translation>
     </message>
+    <message>
+        <location filename="../Plugins/CheckerPlugins/SyntaxChecker/SyntaxCheckService.py" line="273"/>
+        <source>TOML batch check</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>SyntaxCheckerDialog</name>
@@ -71297,22 +71302,22 @@
 <context>
     <name>SyntaxCheckerPlugin</name>
     <message>
-        <location filename="../Plugins/PluginSyntaxChecker.py" line="261"/>
+        <location filename="../Plugins/PluginSyntaxChecker.py" line="270"/>
         <source>Check Syntax</source>
         <translation>Проверить синтаксис</translation>
     </message>
     <message>
-        <location filename="../Plugins/PluginSyntaxChecker.py" line="261"/>
+        <location filename="../Plugins/PluginSyntaxChecker.py" line="270"/>
         <source>&amp;Syntax...</source>
         <translation>&amp;Синтаксис...</translation>
     </message>
     <message>
-        <location filename="../Plugins/PluginSyntaxChecker.py" line="170"/>
+        <location filename="../Plugins/PluginSyntaxChecker.py" line="179"/>
         <source>Check syntax.</source>
         <translation>Проверить синтаксис.</translation>
     </message>
     <message>
-        <location filename="../Plugins/PluginSyntaxChecker.py" line="265"/>
+        <location filename="../Plugins/PluginSyntaxChecker.py" line="274"/>
         <source>&lt;b&gt;Check Syntax...&lt;/b&gt;&lt;p&gt;This checks Python files for syntax errors.&lt;/p&gt;</source>
         <translation>&lt;b&gt;Проверить синтаксис...&lt;/b&gt;&lt;p&gt;Проверка файлов Python на синтаксические ошибки.&lt;/p&gt;</translation>
     </message>
--- a/eric6/i18n/eric6_tr.ts	Sun Oct 04 18:03:33 2020 +0200
+++ b/eric6/i18n/eric6_tr.ts	Sun Oct 04 18:53:35 2020 +0200
@@ -74285,6 +74285,11 @@
         <source>JSON batch check</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <location filename="../Plugins/CheckerPlugins/SyntaxChecker/SyntaxCheckService.py" line="273"/>
+        <source>TOML batch check</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>SyntaxCheckerDialog</name>
@@ -74394,22 +74399,22 @@
 <context>
     <name>SyntaxCheckerPlugin</name>
     <message>
-        <location filename="../Plugins/PluginSyntaxChecker.py" line="261"/>
+        <location filename="../Plugins/PluginSyntaxChecker.py" line="270"/>
         <source>Check Syntax</source>
         <translation>Sözdizimi Kontrolü</translation>
     </message>
     <message>
-        <location filename="../Plugins/PluginSyntaxChecker.py" line="261"/>
+        <location filename="../Plugins/PluginSyntaxChecker.py" line="270"/>
         <source>&amp;Syntax...</source>
         <translation>&amp;Sözdizimi...</translation>
     </message>
     <message>
-        <location filename="../Plugins/PluginSyntaxChecker.py" line="170"/>
+        <location filename="../Plugins/PluginSyntaxChecker.py" line="179"/>
         <source>Check syntax.</source>
         <translation>Sözdizimini kontrol et.</translation>
     </message>
     <message>
-        <location filename="../Plugins/PluginSyntaxChecker.py" line="265"/>
+        <location filename="../Plugins/PluginSyntaxChecker.py" line="274"/>
         <source>&lt;b&gt;Check Syntax...&lt;/b&gt;&lt;p&gt;This checks Python files for syntax errors.&lt;/p&gt;</source>
         <translation>&lt;b&gt;Sözdizimini Kontrol Et...&lt;/b&gt;&lt;p&gt;Bu kontrol Python dosyalarını sözdizimi hatalarına karşı yapılır.&lt;/p&gt;</translation>
     </message>
--- a/eric6/i18n/eric6_zh_CN.ts	Sun Oct 04 18:03:33 2020 +0200
+++ b/eric6/i18n/eric6_zh_CN.ts	Sun Oct 04 18:53:35 2020 +0200
@@ -75209,6 +75209,11 @@
         <source>JSON batch check</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <location filename="../Plugins/CheckerPlugins/SyntaxChecker/SyntaxCheckService.py" line="273"/>
+        <source>TOML batch check</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>SyntaxCheckerDialog</name>
@@ -75319,22 +75324,22 @@
 <context>
     <name>SyntaxCheckerPlugin</name>
     <message>
-        <location filename="../Plugins/PluginSyntaxChecker.py" line="261"/>
+        <location filename="../Plugins/PluginSyntaxChecker.py" line="270"/>
         <source>Check Syntax</source>
         <translation>检查语法</translation>
     </message>
     <message>
-        <location filename="../Plugins/PluginSyntaxChecker.py" line="261"/>
+        <location filename="../Plugins/PluginSyntaxChecker.py" line="270"/>
         <source>&amp;Syntax...</source>
         <translation>语法(&amp;S)…</translation>
     </message>
     <message>
-        <location filename="../Plugins/PluginSyntaxChecker.py" line="170"/>
+        <location filename="../Plugins/PluginSyntaxChecker.py" line="179"/>
         <source>Check syntax.</source>
         <translation>检查语法。</translation>
     </message>
     <message>
-        <location filename="../Plugins/PluginSyntaxChecker.py" line="265"/>
+        <location filename="../Plugins/PluginSyntaxChecker.py" line="274"/>
         <source>&lt;b&gt;Check Syntax...&lt;/b&gt;&lt;p&gt;This checks Python files for syntax errors.&lt;/p&gt;</source>
         <translation>&lt;b&gt;检查语法…&lt;/b&gt;&lt;p&gt;检查 Python 文件的语法错误。&lt;/p&gt;</translation>
     </message>

eric ide

mercurial
--- a/eric6/Plugins/PluginSyntaxChecker.py	Sun Oct 04 18:03:33 2020 +0200
+++ b/eric6/Plugins/PluginSyntaxChecker.py	Sun Oct 04 18:53:35 2020 +0200
@@ -101,7 +101,15 @@
                 self.syntaxCheckService.syntaxChecked.emit(fn, problems),
             self.syntaxCheckService.serviceErrorJSON)
         
-        # TODO: add syntax check for TOML using the toml package
+        # TOML syntax check via Python3
+        self.syntaxCheckService.addLanguage(
+            'TOML', 'Python3', path,
+            'tomlCheckSyntax',
+            lambda: [],  # No options
+            lambda: ['.toml'],
+            lambda fn, problems:
+                self.syntaxCheckService.syntaxChecked.emit(fn, problems),
+            self.syntaxCheckService.serviceErrorTOML)
 
     def __initialize(self):
         """